/** 
 * Binary Indexed Tree 2D - BIT2D
 * Complexity (Time):
 *   Update -> O(log^2 n)
 *   Query  -> O(log^2 n)
 *
 * Complexity (Space): O(n^2)
 */

int tree[MAXN][MAXM];

// Perform query in array (tree) in the (idx,idy) position
int query(int idx, int idy) {
  int sum = 0, m;
  for (; idx > 0; idx -= (idx & -idx))
    for (m = idy; m > 0; m -= (m & -m))
      sum += tree[idx][m];

  return sum;
}

// Add a value (val) to a single position (idx,idy) in the array (tree).
void update(int idx, int idy, int val) {
  int m;
  for (; idx <= MAXN; idx += (idx & -idx))
    for (m = idy; m <= MAXM; m += (m & -m))
      tree[idx][m] += val;
}
